@@ -3,7 +3,7 @@ import shutil
 import warnings
 from html import escape
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, Optional, Set, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, Optional, Set, Tuple
 
 import fsspec
 import numpy as np
@@ -14,11 +14,9 @@ from zarr.errors import GroupNotFoundError, PathNotFoundError
 if TYPE_CHECKING:
     from ..core import EngineHint, FileFormatHint, PathHint, SonarModelsHint
 
-from ..calibrate.env_params import EnvParams
 from ..utils.coding import set_time_encodings
 from ..utils.io import check_file_existence, sanitize_file_path
 from ..utils.log import _init_logger
-from ..utils.uwa import calc_sound_speed
 from .convention import sonarnetcdf_1
 from .sensor_ep_version_mapping import ep_version_mapper
 from .widgets.utils import tree_repr
@@ -57,7 +55,6 @@ class EchoData:
         open_kwargs: Optional[Dict[str, Any]] = None,
         parsed2zarr_obj=None,
     ):
-
         # TODO: consider if should open datasets in init
         #  or within each function call when echodata is used. Need to benchmark.
 
@@ -80,12 +77,10 @@ class EchoData:
         self._varattrs = sonarnetcdf_1.yaml_dict["variable_and_varattributes"]
 
     def __del__(self):
-
         # TODO: this destructor seems to not work in Jupyter Lab if restart or
         #  even clear all outputs is used. It will work if you explicitly delete the object
 
         if (self.parsed2zarr_obj is not None) and (self.parsed2zarr_obj.zarr_file_name is not None):
-
             # get Path object of temporary zarr file created by Parsed2Zarr
             p2z_temp_file = Path(self.parsed2zarr_obj.zarr_file_name)
 
@@ -208,6 +203,10 @@ class EchoData:
                 return tuple([int(i) for i in version_num])
         return None
 
+    @property
+    def nbytes(self) -> float:
+        return float(sum(self[p].nbytes for p in self.group_paths))
+
     @property
     def group_paths(self) -> Set[str]:
         return {i[1:] if i != "/" else "Top-level" for i in self._tree.groups}
@@ -261,306 +260,6 @@ class EchoData:
                         self._tree[group_path].ds = __value
         super().__setattr__(__name, attr_value)
 
-    @staticmethod
-    def _harmonize_env_param_time(
-        p: Union[int, float, xr.DataArray],
-        ping_time: Optional[Union[xr.DataArray, datetime.datetime]] = None,
-    ):
-        """
-        Harmonize time coordinate between Beam_groupX data and env_params to make sure
-        the timestamps are broadcast correctly in calibration and range calculations.
-
-        Regardless of the source, if `p` is an xr.DataArray, the time coordinate name
-        needs to be `time1` to be consistent with the time coordinate in EchoData["Environment"].
-        If `time1` is of length=1, the dimension `time1` is dropped.
-        Otherwise, `p` is interpolated to `ping_time`.
-        If `p` is not an xr.DataArray it is returned directly.
-
-        Parameters
-        ----------
-        p
-            The environment parameter for timestamp check/correction
-        ping_time
-            Beam_groupX ping_time to interpolate env_params timestamps to.
-            Only used if p.time1 has length >1
-
-        Returns
-        -------
-        Environment parameter with correctly broadcasted timestamps
-        """
-        if isinstance(p, xr.DataArray):
-            if "time1" not in p.coords:
-                return p
-            else:
-                # If there's only 1 time1 value,
-                # or if after dropping NaN there's only 1 time1 value
-                if p["time1"].size == 1 or p.dropna(dim="time1").size == 1:
-                    return p.dropna(dim="time1").squeeze(dim="time1").drop("time1")
-
-                # Direct assignment if all timestamps are identical (EK60 data)
-                elif np.all(p["time1"].values == ping_time.values):
-                    return p.rename({"time1": "ping_time"})
-
-                elif ping_time is None:
-                    raise ValueError(f"ping_time needs to be provided for interpolating {p.name}")
-
-                else:
-                    return p.dropna(dim="time1").interp(time1=ping_time)
-        else:
-            return p
-
-    def compute_range(
-        self,
-        env_params=None,
-        azfp_cal_type=None,
-        ek_waveform_mode=None,
-        ek_encode_mode="complex",
-    ):
-        """
-        Computes the range (``echo_range``) of the data contained in this ``EchoData``
-        object, in meters.
-
-        Currently this operation is supported for the following ``sonar_model``:
-        EK60, AZFP, EK80 (see Notes below for detail).
-
-        Parameters
-        ----------
-        env_params : dict
-            Environmental parameters needed for computing range (``echo_range``).
-            Users can supply `"sound speed"` directly,
-            or specify other variables that can be used to compute them,
-            including `"temperature"`, `"salinity"`, and `"pressure"`.
-
-            For EK60 and EK80 echosounders, by default echopype uses
-            environmental variables stored in the data files.
-            For AZFP echosounder, all environmental parameters need to be supplied.
-            AZFP echosounders typically are equipped with an internal temperature
-            sensor, and some are equipped with a pressure sensor, but automatically
-            using these pressure data is not currently supported.
-
-        azfp_cal_type : {"Sv", "TS"}, optional
-
-            - `"Sv"` for calculating volume backscattering strength
-            - `"TS"` for calculating target strength.
-
-            This parameter needs to be specified for data from the AZFP echosounder,
-            due to a difference in computing range (``echo_range``) for Sv and TS.
-
-        ek_waveform_mode : {"CW", "BB"}, optional
-            Type of transmit waveform.
-            Required only for data from the EK80 echosounder.
-
-            - `"CW"` for narrowband transmission,
-              returned echoes recorded either as complex or power/angle samples
-            - `"BB"` for broadband transmission,
-              returned echoes recorded as complex samples
-
-        ek_encode_mode : {"complex", "power"}, optional
-            Type of encoded return echo data.
-            Required only for data from the EK80 echosounder.
-
-            - `"complex"` for complex samples
-            - `"power"` for power/angle samples, only allowed when
-              the echosounder is configured for narrowband transmission
-
-        Returns
-        -------
-        xr.DataArray
-            The range (``echo_range``) of the data in meters.
-
-        Raises
-        ------
-        ValueError
-            - When `sonar_model` is `"AZFP"` but `azfp_cal_type` is not specified or is `None`.
-            - When `sonar_model` is `"EK80"` but `ek_waveform_mode` is not specified or is `None`.
-            - When `sonar_model` is `"EK60"` but `waveform_mode` is `"BB"`
-            - When `sonar_model` is `"AZFP"` and `env_params` does not contain
-              either `"sound_speed"` or all of `"temperature"`, `"salinity"`, and `"pressure"`.
-            - When `sonar_model` is `"EK60"` or `"EK80"`,
-              EchoData["Environment"].sound_speed_indicative does not exist,
-              and `env_params` does not contain either `"sound_speed"`
-              or all of `"temperature"`, `"salinity"`, and `"pressure"`.
-            - When `sonar_model` is not `"AZFP"`, `"EK60"`, or `"EK80"`.
-
-        Notes
-        -----
-        The EK80 echosounder can be configured to transmit
-        either broadband (``waveform_mode="BB"``)
-        or narrowband (``waveform_mode="CW"``) signals.
-        When transmitting in broadband mode, the returned echoes are
-        encoded as complex samples (``encode_mode="complex"``).
-        When transmitting in narrowband mode, the returned echoes can be encoded
-        either as complex samples (``encode_mode="complex"``)
-        or as power/angle combinations (``encode_mode="power"``) in a format
-        similar to those recorded by EK60 echosounders.
-
-        For AZFP echosounder, the returned ``echo_range`` is duplicated along ``ping_time``
-        to conform with outputs from other echosounders, even though within each data
-        file the range is held constant.
-        """
-
-        if isinstance(env_params, EnvParams):
-            env_params = env_params._apply(self)
-
-        if "sound_speed" in env_params:
-            sound_speed = env_params["sound_speed"]
-        elif (
-            self.sonar_model in ("EK60", "EK80") and "sound_speed_indicative" in self["Environment"]
-        ):
-            sound_speed = self["Environment"]["sound_speed_indicative"]
-        elif all([param in env_params for param in ("temperature", "salinity", "pressure")]):
-            sound_speed = calc_sound_speed(
-                env_params["temperature"],
-                env_params["salinity"],
-                env_params["pressure"],
-                formula_source="AZFP" if self.sonar_model == "AZFP" else "Mackenzie",
-            )
-        else:
-            raise ValueError(
-                "sound speed must be specified in env_params, "
-                "with temperature, salinity, and pressure all specified in env_params "
-                "for sound speed to be calculated, "
-                "or in EchoData['Environment'].sound_speed_indicative "
-                "for EK60 and EK80 sonar models"
-            )
-
-        # AZFP
-        if self.sonar_model == "AZFP":
-            cal_type = azfp_cal_type
-            if cal_type is None:
-                raise ValueError("azfp_cal_type must be specified when sonar_model is AZFP")
-
-            # Notation below follows p.86 of user manual
-            N = self["Vendor_specific"]["number_of_samples_per_average_bin"]  # samples per bin
-            f = self["Vendor_specific"]["digitization_rate"]  # digitization rate
-            L = self["Vendor_specific"]["lockout_index"]  # number of lockout samples
-
-            # keep this in ref of AZFP matlab code,
-            # set to 1 since we want to calculate from raw data
-            bins_to_avg = 1
-
-            # Harmonize sound_speed time1 and Beam_group1 ping_time
-            sound_speed = self._harmonize_env_param_time(
-                p=sound_speed,
-                ping_time=self["Sonar/Beam_group1"].ping_time,
-            )
-
-            # Calculate range using parameters for each freq
-            # This is "the range to the centre of the sampling volume
-            # for bin m" from p.86 of user manual
-            if cal_type == "Sv":
-                range_offset = 0
-            else:
-                range_offset = (
-                    sound_speed * self["Sonar/Beam_group1"]["transmit_duration_nominal"] / 4
-                )  # from matlab code
-            range_meter = (
-                sound_speed * L / (2 * f)
-                + (sound_speed / 4)
-                * (
-                    ((2 * (self["Sonar/Beam_group1"].range_sample + 1) - 1) * N * bins_to_avg - 1)
-                    / f
-                    + self["Sonar/Beam_group1"]["transmit_duration_nominal"]
-                )
-                - range_offset
-            )
-
-            range_meter.name = "echo_range"  # add name to facilitate xr.merge
-
-            return range_meter
-
-        # EK
-        elif self.sonar_model in ("EK60", "EK80", "ES70", "ES80", "EA640"):
-            waveform_mode = ek_waveform_mode
-            encode_mode = ek_encode_mode
-
-            # EK60 can only be CW mode
-            if self.sonar_model == "EK60":
-                if waveform_mode is None:
-                    waveform_mode = "CW"  # default to CW mode
-                elif waveform_mode != "CW":
-                    raise ValueError("EK60 must have CW samples")
-
-            # EK80 needs waveform_mode specification
-            if self.sonar_model == "EK80" and waveform_mode is None:
-                raise ValueError("ek_waveform_mode must be specified when sonar_model is EK80")
-
-            # TVG correction factor changes depending when the echo recording starts
-            # wrt when the transmit signal is sent out.
-            # This implementation is different for EK60 and EK80.
-            tvg_correction_factor = TVG_CORRECTION_FACTOR[self.sonar_model]
-
-            if waveform_mode == "CW":
-                if (
-                    self.sonar_model == "EK80"
-                    and encode_mode == "power"
-                    and self["Sonar/Beam_group2"] is not None
-                ):
-                    # if both CW and BB exist and beam_power group is not empty
-                    # this means that CW is recorded in power/angle mode
-                    beam = self["Sonar/Beam_group2"]
-                else:
-                    beam = self["Sonar/Beam_group1"]
-
-                # Harmonize sound_speed time1 and Beam_groupX ping_time
-                sound_speed = self._harmonize_env_param_time(
-                    p=sound_speed,
-                    ping_time=beam.ping_time,
-                )
-
-                sample_thickness = beam["sample_interval"] * sound_speed / 2
-                # TODO: Check with the AFSC about the half sample difference
-                range_meter = (
-                    beam.range_sample - tvg_correction_factor
-                ) * sample_thickness  # [frequency x range_sample]
-            elif waveform_mode == "BB":
-                beam = self["Sonar/Beam_group1"]  # always use the Beam group
-                # TODO: bug: right now only first ping_time has non-nan range
-                shift = beam["transmit_duration_nominal"]  # based on Lar Anderson's Matlab code
-
-                # Harmonize sound_speed time1 and Beam_group1 ping_time
-                sound_speed = self._harmonize_env_param_time(
-                    p=sound_speed,
-                    ping_time=beam.ping_time,
-                )
-
-                # TODO: once we allow putting in arbitrary sound_speed,
-                # change below to use linearly-interpolated values
-                range_meter = (
-                    (beam.range_sample * beam["sample_interval"] - shift) * sound_speed / 2
-                )
-                # TODO: Lar Anderson's code include a slicing by minRange with a default of 0.02 m,
-                #  need to ask why and see if necessary here
-            else:
-                raise ValueError("Input waveform_mode not recognized!")
-
-            # make order of dims conform with the order of backscatter data
-            range_meter = range_meter.transpose("channel", "ping_time", "range_sample")
-            range_meter = range_meter.where(range_meter > 0, 0)  # set negative ranges to 0
-
-            # set entries with NaN backscatter data to NaN
-            if "beam" in beam["backscatter_r"].dims:
-                # Drop beam because echo_range does not have beam dimension
-                valid_idx = ~beam["backscatter_r"].isel(beam=0).drop("beam").isnull()
-            else:
-                valid_idx = ~beam["backscatter_r"].isnull()
-            range_meter = range_meter.where(valid_idx)
-
-            # remove time1 if exists as a coordinate
-            if "time1" in range_meter.coords:
-                range_meter = range_meter.drop("time1")
-
-            # add name to facilitate xr.merge
-            range_meter.name = "echo_range"
-
-            return range_meter
-
-        # OTHERS
-        else:
-            raise ValueError(
-                "this method only supports the following sonar_model: AZFP, EK60, and EK80"
-            )
-
     def update_platform(
         self,
         extra_platform_data: xr.Dataset,
@@ -785,7 +484,15 @@ class EchoData:
             **self.open_kwargs,
         )
 
-    def to_netcdf(self, save_path: Optional["PathHint"] = None, **kwargs):
+    def to_netcdf(
+        self,
+        save_path: Optional["PathHint"] = None,
+        compress: bool = True,
+        overwrite: bool = False,
+        parallel: bool = False,
+        output_storage_options: Dict[str, str] = {},
+        **kwargs,
+    ):
         """Save content of EchoData to netCDF.
 
         Parameters
@@ -802,12 +509,33 @@ class EchoData:
             whether or not to use parallel processing. (Not yet implemented)
         output_storage_options : dict
             Additional keywords to pass to the filesystem class.
+        **kwargs : dict, optional
+            Extra arguments to `xr.Dataset.to_netcdf`: refer to
+            xarray's documentation for a list of all possible arguments.
         """
         from ..convert.api import to_file
 
-        return to_file(self, "netcdf4", save_path=save_path, **kwargs)
+        return to_file(
+            echodata=self,
+            engine="netcdf4",
+            save_path=save_path,
+            compress=compress,
+            overwrite=overwrite,
+            parallel=parallel,
+            output_storage_options=output_storage_options,
+            **kwargs,
+        )
 
-    def to_zarr(self, save_path: Optional["PathHint"] = None, **kwargs):
+    def to_zarr(
+        self,
+        save_path: Optional["PathHint"] = None,
+        compress: bool = True,
+        overwrite: bool = False,
+        parallel: bool = False,
+        output_storage_options: Dict[str, str] = {},
+        consolidated: bool = True,
+        **kwargs,
+    ):
         """Save content of EchoData to zarr.
 
         Parameters
@@ -824,10 +552,26 @@ class EchoData:
             whether or not to use parallel processing. (Not yet implemented)
         output_storage_options : dict
             Additional keywords to pass to the filesystem class.
+        consolidated : bool
+            Flag to consolidate zarr metadata.
+            Defaults to ``True``
+        **kwargs : dict, optional
+            Extra arguments to `xr.Dataset.to_zarr`: refer to
+            xarray's documentation for a list of all possible arguments.
         """
         from ..convert.api import to_file
 
-        return to_file(self, "zarr", save_path=save_path, **kwargs)
+        return to_file(
+            echodata=self,
+            engine="zarr",
+            save_path=save_path,
+            compress=compress,
+            overwrite=overwrite,
+            parallel=parallel,
+            output_storage_options=output_storage_options,
+            consolidated=consolidated,
+            **kwargs,
+        )
 
     # TODO: Remove below in future versions. They are for supporting old API calls.
     @property
